# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/order.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.clob import liquidations_pb2 as dydxprotocol_dot_clob_dot_liquidations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/clob/order.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a$dydxprotocol/clob/liquidations.proto\"\x8c\x01\n\x07OrderId\x12\x43\n\rsubaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x11\n\tclient_id\x18\x02 \x01(\x07\x12\x13\n\x0border_flags\x18\x03 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x04 \x01(\r\"T\n\x1dOrdersFilledDuringLatestBlock\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"P\n\x19PotentiallyPrunableOrders\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"D\n\x0eOrderFillState\x12\x13\n\x0b\x66ill_amount\x18\x01 \x01(\x04\x12\x1d\n\x15prunable_block_height\x18\x02 \x01(\r\"R\n\x1bStatefulOrderTimeSliceValue\x12\x33\n\torder_ids\x18\x01 \x03(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\"\x8e\x01\n\x16LongTermOrderPlacement\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x45\n\x0fplacement_index\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrderingB\x04\xc8\xde\x1f\x00\"\xd0\x01\n\x19\x43onditionalOrderPlacement\x12-\n\x05order\x18\x01 \x01(\x0b\x32\x18.dydxprotocol.clob.OrderB\x04\xc8\xde\x1f\x00\x12\x45\n\x0fplacement_index\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrderingB\x04\xc8\xde\x1f\x00\x12=\n\rtrigger_index\x18\x03 \x01(\x0b\x32&.dydxprotocol.clob.TransactionOrdering\"\xdf\x05\n\x05Order\x12\x32\n\x08order_id\x18\x01 \x01(\x0b\x32\x1a.dydxprotocol.clob.OrderIdB\x04\xc8\xde\x1f\x00\x12+\n\x04side\x18\x02 \x01(\x0e\x32\x1d.dydxprotocol.clob.Order.Side\x12\x10\n\x08quantums\x18\x03 \x01(\x04\x12\x10\n\x08subticks\x18\x04 \x01(\x04\x12\x18\n\x0egood_til_block\x18\x05 \x01(\rH\x00\x12\x1d\n\x13good_til_block_time\x18\x06 \x01(\x07H\x00\x12;\n\rtime_in_force\x18\x07 \x01(\x0e\x32$.dydxprotocol.clob.Order.TimeInForce\x12\x13\n\x0breduce_only\x18\x08 \x01(\x08\x12\x17\n\x0f\x63lient_metadata\x18\t \x01(\r\x12>\n\x0e\x63ondition_type\x18\n \x01(\x0e\x32&.dydxprotocol.clob.Order.ConditionType\x12*\n\"conditional_order_trigger_subticks\x18\x0b \x01(\x04\"9\n\x04Side\x12\x14\n\x10SIDE_UNSPECIFIED\x10\x00\x12\x0c\n\x08SIDE_BUY\x10\x01\x12\r\n\tSIDE_SELL\x10\x02\"\x84\x01\n\x0bTimeInForce\x12\x1d\n\x19TIME_IN_FORCE_UNSPECIFIED\x10\x00\x12\x15\n\x11TIME_IN_FORCE_IOC\x10\x01\x12\x1b\n\x17TIME_IN_FORCE_POST_ONLY\x10\x02\x12\"\n\x1aTIME_IN_FORCE_FILL_OR_KILL\x10\x03\x1a\x02\x08\x01\"m\n\rConditionType\x12\x1e\n\x1a\x43ONDITION_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18\x43ONDITION_TYPE_STOP_LOSS\x10\x01\x12\x1e\n\x1a\x43ONDITION_TYPE_TAKE_PROFIT\x10\x02\x42\x10\n\x0egood_til_oneof\"F\n\x13TransactionOrdering\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\r\x12\x19\n\x11transaction_index\x18\x02 \x01(\r\"\xa9\x01\n\x16StreamLiquidationOrder\x12\x45\n\x10liquidation_info\x18\x01 \x01(\x0b\x32+.dydxprotocol.clob.PerpetualLiquidationInfo\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06is_buy\x18\x03 \x01(\x08\x12\x10\n\x08quantums\x18\x04 \x01(\x04\x12\x10\n\x08subticks\x18\x05 \x01(\x04\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_ORDERID'].fields_by_name['subaccount_id']._loaded_options = None
  _globals['_ORDERID'].fields_by_name['subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK'].fields_by_name['order_ids']._loaded_options = None
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_POTENTIALLYPRUNABLEORDERS'].fields_by_name['order_ids']._loaded_options = None
  _globals['_POTENTIALLYPRUNABLEORDERS'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_STATEFULORDERTIMESLICEVALUE'].fields_by_name['order_ids']._loaded_options = None
  _globals['_STATEFULORDERTIMESLICEVALUE'].fields_by_name['order_ids']._serialized_options = b'\310\336\037\000'
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['order']._loaded_options = None
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['placement_index']._loaded_options = None
  _globals['_LONGTERMORDERPLACEMENT'].fields_by_name['placement_index']._serialized_options = b'\310\336\037\000'
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['order']._loaded_options = None
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['order']._serialized_options = b'\310\336\037\000'
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['placement_index']._loaded_options = None
  _globals['_CONDITIONALORDERPLACEMENT'].fields_by_name['placement_index']._serialized_options = b'\310\336\037\000'
  _globals['_ORDER_TIMEINFORCE'].values_by_name["TIME_IN_FORCE_FILL_OR_KILL"]._loaded_options = None
  _globals['_ORDER_TIMEINFORCE'].values_by_name["TIME_IN_FORCE_FILL_OR_KILL"]._serialized_options = b'\010\001'
  _globals['_ORDER'].fields_by_name['order_id']._loaded_options = None
  _globals['_ORDER'].fields_by_name['order_id']._serialized_options = b'\310\336\037\000'
  _globals['_ORDERID']._serialized_start=156
  _globals['_ORDERID']._serialized_end=296
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK']._serialized_start=298
  _globals['_ORDERSFILLEDDURINGLATESTBLOCK']._serialized_end=382
  _globals['_POTENTIALLYPRUNABLEORDERS']._serialized_start=384
  _globals['_POTENTIALLYPRUNABLEORDERS']._serialized_end=464
  _globals['_ORDERFILLSTATE']._serialized_start=466
  _globals['_ORDERFILLSTATE']._serialized_end=534
  _globals['_STATEFULORDERTIMESLICEVALUE']._serialized_start=536
  _globals['_STATEFULORDERTIMESLICEVALUE']._serialized_end=618
  _globals['_LONGTERMORDERPLACEMENT']._serialized_start=621
  _globals['_LONGTERMORDERPLACEMENT']._serialized_end=763
  _globals['_CONDITIONALORDERPLACEMENT']._serialized_start=766
  _globals['_CONDITIONALORDERPLACEMENT']._serialized_end=974
  _globals['_ORDER']._serialized_start=977
  _globals['_ORDER']._serialized_end=1712
  _globals['_ORDER_SIDE']._serialized_start=1391
  _globals['_ORDER_SIDE']._serialized_end=1448
  _globals['_ORDER_TIMEINFORCE']._serialized_start=1451
  _globals['_ORDER_TIMEINFORCE']._serialized_end=1583
  _globals['_ORDER_CONDITIONTYPE']._serialized_start=1585
  _globals['_ORDER_CONDITIONTYPE']._serialized_end=1694
  _globals['_TRANSACTIONORDERING']._serialized_start=1714
  _globals['_TRANSACTIONORDERING']._serialized_end=1784
  _globals['_STREAMLIQUIDATIONORDER']._serialized_start=1787
  _globals['_STREAMLIQUIDATIONORDER']._serialized_end=1956
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/gov/v1beta1/gov.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/gov/v1beta1/gov.proto\x12\x12\x63osmos.gov.v1beta1\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x8c\x01\n\x12WeightedVoteOption\x12.\n\x06option\x18\x01 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOption\x12\x46\n\x06weight\x18\x02 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\"r\n\x0cTextProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t:>\xe8\xa0\x1f\x01\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x8a\xe7\xb0*\x17\x63osmos-sdk/TextProposal\"\xb7\x01\n\x07\x44\x65posit\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12+\n\tdepositor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12`\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xe0\x04\n\x08Proposal\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\x45\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x1e\xca\xb4-\x1a\x63osmos.gov.v1beta1.Content\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".cosmos.gov.v1beta1.ProposalStatus\x12\x46\n\x12\x66inal_tally_result\x18\x04 \x01(\x0b\x32\x1f.cosmos.gov.v1beta1.TallyResultB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12>\n\x0bsubmit_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x43\n\x10\x64\x65posit_end_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12g\n\rtotal_deposit\x18\x07 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB5\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xa8\xe7\xb0*\x01\x12\x44\n\x11voting_start_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x42\n\x0fvoting_end_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\r\xc8\xde\x1f\x00\x90\xdf\x1f\x01\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x01\"\x87\x02\n\x0bTallyResult\x12\x38\n\x03yes\x18\x01 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12<\n\x07\x61\x62stain\x18\x02 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12\x37\n\x02no\x18\x03 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int\x12\x41\n\x0cno_with_veto\x18\x04 \x01(\tB+\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.Int\xd2\xb4-\ncosmos.Int:\x04\xe8\xa0\x1f\x01\"\xd6\x01\n\x04Vote\x12\'\n\x0bproposal_id\x18\x01 \x01(\x04\x42\x12\xea\xde\x1f\x02id\xa2\xe7\xb0*\x02id\xa8\xe7\xb0*\x01\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x32\n\x06option\x18\x03 \x01(\x0e\x32\x1e.cosmos.gov.v1beta1.VoteOptionB\x02\x18\x01\x12\x42\n\x07options\x18\x04 \x03(\x0b\x32&.cosmos.gov.v1beta1.WeightedVoteOptionB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:\x04\xe8\xa0\x1f\x00\"\xeb\x01\n\rDepositParams\x12y\n\x0bmin_deposit\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBI\xc8\xde\x1f\x00\xea\xde\x1f\x15min_deposit,omitempty\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12_\n\x12max_deposit_period\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB(\xc8\xde\x1f\x00\xea\xde\x1f\x1cmax_deposit_period,omitempty\x98\xdf\x1f\x01\"e\n\x0cVotingParams\x12U\n\rvoting_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB#\xc8\xde\x1f\x00\xea\xde\x1f\x17voting_period,omitempty\x98\xdf\x1f\x01\"\xa8\x02\n\x0bTallyParams\x12U\n\x06quorum\x18\x01 \x01(\x0c\x42\x45\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xea\xde\x1f\x10quorum,omitempty\xd2\xb4-\ncosmos.Dec\x12[\n\tthreshold\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xea\xde\x1f\x13threshold,omitempty\xd2\xb4-\ncosmos.Dec\x12\x65\n\x0eveto_threshold\x18\x03 \x01(\x0c\x42M\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xea\xde\x1f\x18veto_threshold,omitempty\xd2\xb4-\ncosmos.Dec*\xe6\x01\n\nVoteOption\x12,\n\x17VOTE_OPTION_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bOptionEmpty\x12\"\n\x0fVOTE_OPTION_YES\x10\x01\x1a\r\x8a\x9d \tOptionYes\x12*\n\x13VOTE_OPTION_ABSTAIN\x10\x02\x1a\x11\x8a\x9d \rOptionAbstain\x12 \n\x0eVOTE_OPTION_NO\x10\x03\x1a\x0c\x8a\x9d \x08OptionNo\x12\x32\n\x18VOTE_OPTION_NO_WITH_VETO\x10\x04\x1a\x14\x8a\x9d \x10OptionNoWithVeto\x1a\x04\x88\xa3\x1e\x00*\xcc\x02\n\x0eProposalStatus\x12.\n\x1bPROPOSAL_STATUS_UNSPECIFIED\x10\x00\x1a\r\x8a\x9d \tStatusNil\x12;\n\x1ePROPOSAL_STATUS_DEPOSIT_PERIOD\x10\x01\x1a\x17\x8a\x9d \x13StatusDepositPeriod\x12\x39\n\x1dPROPOSAL_STATUS_VOTING_PERIOD\x10\x02\x1a\x16\x8a\x9d \x12StatusVotingPeriod\x12,\n\x16PROPOSAL_STATUS_PASSED\x10\x03\x1a\x10\x8a\x9d \x0cStatusPassed\x12\x30\n\x18PROPOSAL_STATUS_REJECTED\x10\x04\x1a\x12\x8a\x9d \x0eStatusRejected\x12,\n\x16PROPOSAL_STATUS_FAILED\x10\x05\x1a\x10\x8a\x9d \x0cStatusFailed\x1a\x04\x88\xa3\x1e\x00\x42\x36Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1\xc8\xe1\x1e\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.gov.v1beta1.gov_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z0github.com/cosmos/cosmos-sdk/x/gov/types/v1beta1\310\341\036\000'
  _globals['_VOTEOPTION']._loaded_options = None
  _globals['_VOTEOPTION']._serialized_options = b'\210\243\036\000'
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_UNSPECIFIED"]._loaded_options = None
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_UNSPECIFIED"]._serialized_options = b'\212\235 \013OptionEmpty'
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_YES"]._loaded_options = None
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_YES"]._serialized_options = b'\212\235 \tOptionYes'
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_ABSTAIN"]._loaded_options = None
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_ABSTAIN"]._serialized_options = b'\212\235 \rOptionAbstain'
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_NO"]._loaded_options = None
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_NO"]._serialized_options = b'\212\235 \010OptionNo'
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_NO_WITH_VETO"]._loaded_options = None
  _globals['_VOTEOPTION'].values_by_name["VOTE_OPTION_NO_WITH_VETO"]._serialized_options = b'\212\235 \020OptionNoWithVeto'
  _globals['_PROPOSALSTATUS']._loaded_options = None
  _globals['_PROPOSALSTATUS']._serialized_options = b'\210\243\036\000'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_UNSPECIFIED"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_UNSPECIFIED"]._serialized_options = b'\212\235 \tStatusNil'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_DEPOSIT_PERIOD"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_DEPOSIT_PERIOD"]._serialized_options = b'\212\235 \023StatusDepositPeriod'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_VOTING_PERIOD"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_VOTING_PERIOD"]._serialized_options = b'\212\235 \022StatusVotingPeriod'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_PASSED"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_PASSED"]._serialized_options = b'\212\235 \014StatusPassed'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_REJECTED"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_REJECTED"]._serialized_options = b'\212\235 \016StatusRejected'
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_FAILED"]._loaded_options = None
  _globals['_PROPOSALSTATUS'].values_by_name["PROPOSAL_STATUS_FAILED"]._serialized_options = b'\212\235 \014StatusFailed'
  _globals['_WEIGHTEDVOTEOPTION'].fields_by_name['weight']._loaded_options = None
  _globals['_WEIGHTEDVOTEOPTION'].fields_by_name['weight']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_TEXTPROPOSAL']._loaded_options = None
  _globals['_TEXTPROPOSAL']._serialized_options = b'\350\240\037\001\312\264-\032cosmos.gov.v1beta1.Content\212\347\260*\027cosmos-sdk/TextProposal'
  _globals['_DEPOSIT'].fields_by_name['depositor']._loaded_options = None
  _globals['_DEPOSIT'].fields_by_name['depositor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_DEPOSIT'].fields_by_name['amount']._loaded_options = None
  _globals['_DEPOSIT'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_DEPOSIT']._loaded_options = None
  _globals['_DEPOSIT']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_PROPOSAL'].fields_by_name['content']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['content']._serialized_options = b'\312\264-\032cosmos.gov.v1beta1.Content'
  _globals['_PROPOSAL'].fields_by_name['final_tally_result']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['final_tally_result']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['submit_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['submit_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['deposit_end_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['deposit_end_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['total_deposit']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['total_deposit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['voting_start_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['voting_start_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL'].fields_by_name['voting_end_time']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['voting_end_time']._serialized_options = b'\310\336\037\000\220\337\037\001\250\347\260*\001'
  _globals['_PROPOSAL']._loaded_options = None
  _globals['_PROPOSAL']._serialized_options = b'\350\240\037\001'
  _globals['_TALLYRESULT'].fields_by_name['yes']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['yes']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['abstain']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['abstain']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['no']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['no']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT'].fields_by_name['no_with_veto']._loaded_options = None
  _globals['_TALLYRESULT'].fields_by_name['no_with_veto']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int\322\264-\ncosmos.Int'
  _globals['_TALLYRESULT']._loaded_options = None
  _globals['_TALLYRESULT']._serialized_options = b'\350\240\037\001'
  _globals['_VOTE'].fields_by_name['proposal_id']._loaded_options = None
  _globals['_VOTE'].fields_by_name['proposal_id']._serialized_options = b'\352\336\037\002id\242\347\260*\002id\250\347\260*\001'
  _globals['_VOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_VOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_VOTE'].fields_by_name['option']._loaded_options = None
  _globals['_VOTE'].fields_by_name['option']._serialized_options = b'\030\001'
  _globals['_VOTE'].fields_by_name['options']._loaded_options = None
  _globals['_VOTE'].fields_by_name['options']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_VOTE']._loaded_options = None
  _globals['_VOTE']._serialized_options = b'\350\240\037\000'
  _globals['_DEPOSITPARAMS'].fields_by_name['min_deposit']._loaded_options = None
  _globals['_DEPOSITPARAMS'].fields_by_name['min_deposit']._serialized_options = b'\310\336\037\000\352\336\037\025min_deposit,omitempty\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_DEPOSITPARAMS'].fields_by_name['max_deposit_period']._loaded_options = None
  _globals['_DEPOSITPARAMS'].fields_by_name['max_deposit_period']._serialized_options = b'\310\336\037\000\352\336\037\034max_deposit_period,omitempty\230\337\037\001'
  _globals['_VOTINGPARAMS'].fields_by_name['voting_period']._loaded_options = None
  _globals['_VOTINGPARAMS'].fields_by_name['voting_period']._serialized_options = b'\310\336\037\000\352\336\037\027voting_period,omitempty\230\337\037\001'
  _globals['_TALLYPARAMS'].fields_by_name['quorum']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['quorum']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\352\336\037\020quorum,omitempty\322\264-\ncosmos.Dec'
  _globals['_TALLYPARAMS'].fields_by_name['threshold']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['threshold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\352\336\037\023threshold,omitempty\322\264-\ncosmos.Dec'
  _globals['_TALLYPARAMS'].fields_by_name['veto_threshold']._loaded_options = None
  _globals['_TALLYPARAMS'].fields_by_name['veto_threshold']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\352\336\037\030veto_threshold,omitempty\322\264-\ncosmos.Dec'
  _globals['_VOTEOPTION']._serialized_start=2424
  _globals['_VOTEOPTION']._serialized_end=2654
  _globals['_PROPOSALSTATUS']._serialized_start=2657
  _globals['_PROPOSALSTATUS']._serialized_end=2989
  _globals['_WEIGHTEDVOTEOPTION']._serialized_start=245
  _globals['_WEIGHTEDVOTEOPTION']._serialized_end=385
  _globals['_TEXTPROPOSAL']._serialized_start=387
  _globals['_TEXTPROPOSAL']._serialized_end=501
  _globals['_DEPOSIT']._serialized_start=504
  _globals['_DEPOSIT']._serialized_end=687
  _globals['_PROPOSAL']._serialized_start=690
  _globals['_PROPOSAL']._serialized_end=1298
  _globals['_TALLYRESULT']._serialized_start=1301
  _globals['_TALLYRESULT']._serialized_end=1564
  _globals['_VOTE']._serialized_start=1567
  _globals['_VOTE']._serialized_end=1781
  _globals['_DEPOSITPARAMS']._serialized_start=1784
  _globals['_DEPOSITPARAMS']._serialized_end=2019
  _globals['_VOTINGPARAMS']._serialized_start=2021
  _globals['_VOTINGPARAMS']._serialized_end=2122
  _globals['_TALLYPARAMS']._serialized_start=2125
  _globals['_TALLYPARAMS']._serialized_end=2421
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class QuotingParams(_message.Message):
    __slots__ = ("layers", "spread_min_ppm", "spread_buffer_ppm", "skew_factor_ppm", "order_size_pct_ppm", "order_expiration_seconds", "activation_threshold_quote_quantums")
    LAYERS_FIELD_NUMBER: _ClassVar[int]
    SPREAD_MIN_PPM_FIELD_NUMBER: _ClassVar[int]
    SPREAD_BUFFER_PPM_FIELD_NUMBER: _ClassVar[int]
    SKEW_FACTOR_PPM_FIELD_NUMBER: _ClassVar[int]
    ORDER_SIZE_PCT_PPM_FIELD_NUMBER: _ClassVar[int]
    ORDER_EXPIRATION_SECONDS_FIELD_NUMBER: _ClassVar[int]
    ACTIVATION_THRESHOLD_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    layers: int
    spread_min_ppm: int
    spread_buffer_ppm: int
    skew_factor_ppm: int
    order_size_pct_ppm: int
    order_expiration_seconds: int
    activation_threshold_quote_quantums: bytes
    def __init__(self, layers: _Optional[int] = ..., spread_min_ppm: _Optional[int] = ..., spread_buffer_ppm: _Optional[int] = ..., skew_factor_ppm: _Optional[int] = ..., order_size_pct_ppm: _Optional[int] = ..., order_expiration_seconds: _Optional[int] = ..., activation_threshold_quote_quantums: _Optional[bytes] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("layers", "spread_min_ppm", "spread_buffer_ppm", "skew_factor_ppm", "order_size_pct_ppm", "order_expiration_seconds", "activation_threshold_quote_quantums")
    LAYERS_FIELD_NUMBER: _ClassVar[int]
    SPREAD_MIN_PPM_FIELD_NUMBER: _ClassVar[int]
    SPREAD_BUFFER_PPM_FIELD_NUMBER: _ClassVar[int]
    SKEW_FACTOR_PPM_FIELD_NUMBER: _ClassVar[int]
    ORDER_SIZE_PCT_PPM_FIELD_NUMBER: _ClassVar[int]
    ORDER_EXPIRATION_SECONDS_FIELD_NUMBER: _ClassVar[int]
    ACTIVATION_THRESHOLD_QUOTE_QUANTUMS_FIELD_NUMBER: _ClassVar[int]
    layers: int
    spread_min_ppm: int
    spread_buffer_ppm: int
    skew_factor_ppm: int
    order_size_pct_ppm: int
    order_expiration_seconds: int
    activation_threshold_quote_quantums: bytes
    def __init__(self, layers: _Optional[int] = ..., spread_min_ppm: _Optional[int] = ..., spread_buffer_ppm: _Optional[int] = ..., skew_factor_ppm: _Optional[int] = ..., order_size_pct_ppm: _Optional[int] = ..., order_expiration_seconds: _Optional[int] = ..., activation_threshold_quote_quantums: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/revshare/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.revshare import params_pb2 as dydxprotocol_dot_revshare_dot_params__pb2
from v4_proto.dydxprotocol.revshare import revshare_pb2 as dydxprotocol_dot_revshare_dot_revshare__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/revshare/query.proto\x12\x15\x64ydxprotocol.revshare\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/revshare/params.proto\x1a$dydxprotocol/revshare/revshare.proto\"%\n#QueryMarketMapperRevenueShareParams\"z\n+QueryMarketMapperRevenueShareParamsResponse\x12K\n\x06params\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.revshare.MarketMapperRevenueShareParamsB\x04\xc8\xde\x1f\x00\"5\n QueryMarketMapperRevShareDetails\x12\x11\n\tmarket_id\x18\x01 \x01(\r\"u\n(QueryMarketMapperRevShareDetailsResponse\x12I\n\x07\x64\x65tails\x18\x01 \x01(\x0b\x32\x32.dydxprotocol.revshare.MarketMapperRevShareDetailsB\x04\xc8\xde\x1f\x00\x32\xcf\x03\n\x05Query\x12\xdf\x01\n\x1eMarketMapperRevenueShareParams\x12:.dydxprotocol.revshare.QueryMarketMapperRevenueShareParams\x1a\x42.dydxprotocol.revshare.QueryMarketMapperRevenueShareParamsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/dydxprotocol/revshare/market_mapper_rev_share_params\x12\xe3\x01\n\x1bMarketMapperRevShareDetails\x12\x37.dydxprotocol.revshare.QueryMarketMapperRevShareDetails\x1a?.dydxprotocol.revshare.QueryMarketMapperRevShareDetailsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}B<Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.revshare.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/revshare/types'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._loaded_options = None
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE'].fields_by_name['details']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevenueShareParams']._serialized_options = b'\202\323\344\223\0027\0225/dydxprotocol/revshare/market_mapper_rev_share_params'
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._loaded_options = None
  _globals['_QUERY'].methods_by_name['MarketMapperRevShareDetails']._serialized_options = b'\202\323\344\223\002D\022B/dydxprotocol/revshare/market_mapper_rev_share_details/{market_id}'
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_start=186
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMS']._serialized_end=223
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_start=225
  _globals['_QUERYMARKETMAPPERREVENUESHAREPARAMSRESPONSE']._serialized_end=347
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_start=349
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILS']._serialized_end=402
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_start=404
  _globals['_QUERYMARKETMAPPERREVSHAREDETAILSRESPONSE']._serialized_end=521
  _globals['_QUERY']._serialized_start=524
  _globals['_QUERY']._serialized_end=987
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/rewards/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!dydxprotocol/rewards/params.proto\x12\x14\x64ydxprotocol.rewards\"x\n\x06Params\x12\x18\n\x10treasury_account\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x16\n\x0e\x64\x65nom_exponent\x18\x03 \x01(\x11\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12\x1a\n\x12\x66\x65\x65_multiplier_ppm\x18\x05 \x01(\rB;Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.rewards.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/rewards/types'
  _globals['_PARAMS']._serialized_start=59
  _globals['_PARAMS']._serialized_end=179
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/feegrant/module/v1/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cosmos/feegrant/module/v1/module.proto\x12\x19\x63osmos.feegrant.module.v1\x1a cosmos/app/v1alpha1/module.proto\")\n\x06Module:\x1f\xba\xc0\x96\xda\x01\x19\n\x17\x63osmossdk.io/x/feegrantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.feegrant.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001\031\n\027cosmossdk.io/x/feegrant'
  _globals['_MODULE']._serialized_start=103
  _globals['_MODULE']._serialized_end=144
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class EventGrant(_message.Message):
    __slots__ = ("msg_type_url", "granter", "grantee")
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    msg_type_url: str
    granter: str
    grantee: str
    def __init__(self, msg_type_url: _Optional[str] = ..., granter: _Optional[str] = ..., grantee: _Optional[str] = ...) -> None: ...

class EventRevoke(_message.Message):
    __slots__ = ("msg_type_url", "granter", "grantee")
    MSG_TYPE_URL_FIELD_NUMBER: _ClassVar[int]
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    msg_type_url: str
    granter: str
    grantee: str
    def __init__(self, msg_type_url: _Optional[str] = ..., granter: _Optional[str] = ..., grantee: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/indexer/events/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.indexer.shared import removal_reason_pb2 as dydxprotocol_dot_indexer_dot_shared_dot_removal__reason__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import clob_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_clob__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import perpetual_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_perpetual__pb2
from v4_proto.dydxprotocol.indexer.protocol.v1 import subaccount_pb2 as dydxprotocol_dot_indexer_dot_protocol_dot_v1_dot_subaccount__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(dydxprotocol/indexer/events/events.proto\x12\x1b\x64ydxprotocol.indexer.events\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x30\x64ydxprotocol/indexer/shared/removal_reason.proto\x1a+dydxprotocol/indexer/protocol/v1/clob.proto\x1a\x30\x64ydxprotocol/indexer/protocol/v1/perpetual.proto\x1a\x31\x64ydxprotocol/indexer/protocol/v1/subaccount.proto\"\xa3\x01\n\x0f\x46undingUpdateV1\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12\x19\n\x11\x66unding_value_ppm\x18\x02 \x01(\x05\x12_\n\rfunding_index\x18\x03 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\x84\x02\n\x0e\x46undingEventV1\x12\x43\n\x07updates\x18\x01 \x03(\x0b\x32,.dydxprotocol.indexer.events.FundingUpdateV1B\x04\xc8\xde\x1f\x00\x12>\n\x04type\x18\x02 \x01(\x0e\x32\x30.dydxprotocol.indexer.events.FundingEventV1.Type\"m\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13TYPE_PREMIUM_SAMPLE\x10\x01\x12\x1f\n\x1bTYPE_FUNDING_RATE_AND_INDEX\x10\x02\x12\x15\n\x11TYPE_PREMIUM_VOTE\x10\x03\"\x90\x02\n\rMarketEventV1\x12\x11\n\tmarket_id\x18\x01 \x01(\r\x12M\n\x0cprice_update\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.events.MarketPriceUpdateEventV1H\x00\x12I\n\rmarket_create\x18\x03 \x01(\x0b\x32\x30.dydxprotocol.indexer.events.MarketCreateEventV1H\x00\x12I\n\rmarket_modify\x18\x04 \x01(\x0b\x32\x30.dydxprotocol.indexer.events.MarketModifyEventV1H\x00\x42\x07\n\x05\x65vent\"7\n\x18MarketPriceUpdateEventV1\x12\x1b\n\x13price_with_exponent\x18\x01 \x01(\x04\"?\n\x11MarketBaseEventV1\x12\x0c\n\x04pair\x18\x01 \x01(\t\x12\x1c\n\x14min_price_change_ppm\x18\x02 \x01(\r\"e\n\x13MarketCreateEventV1\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.events.MarketBaseEventV1\x12\x10\n\x08\x65xponent\x18\x02 \x01(\x11\"S\n\x13MarketModifyEventV1\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.events.MarketBaseEventV1\"\x96\x01\n\rSourceOfFunds\x12N\n\rsubaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdH\x00\x12+\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringH\x00\x42\x08\n\x06source\"\xdb\x02\n\x0fTransferEventV1\x12S\n\x14sender_subaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12V\n\x17recipient_subaccount_id\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12\x10\n\x08\x61sset_id\x18\x03 \x01(\r\x12\x0e\n\x06\x61mount\x18\x04 \x01(\x04\x12:\n\x06sender\x18\x05 \x01(\x0b\x32*.dydxprotocol.indexer.events.SourceOfFunds\x12=\n\trecipient\x18\x06 \x01(\x0b\x32*.dydxprotocol.indexer.events.SourceOfFunds\"\xee\x02\n\x10OrderFillEventV1\x12I\n\x0bmaker_order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderB\x04\xc8\xde\x1f\x00\x12?\n\x05order\x18\x02 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderH\x00\x12L\n\x11liquidation_order\x18\x04 \x01(\x0b\x32/.dydxprotocol.indexer.events.LiquidationOrderV1H\x00\x12\x13\n\x0b\x66ill_amount\x18\x03 \x01(\x04\x12\x11\n\tmaker_fee\x18\x05 \x01(\x12\x12\x11\n\ttaker_fee\x18\x06 \x01(\x12\x12\x1a\n\x12total_filled_maker\x18\x07 \x01(\x04\x12\x1a\n\x12total_filled_taker\x18\x08 \x01(\x04\x42\r\n\x0btaker_order\"\xad\x02\n\x13\x44\x65leveragingEventV1\x12O\n\nliquidated\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12O\n\noffsetting\x18\x02 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cperpetual_id\x18\x03 \x01(\r\x12\x13\n\x0b\x66ill_amount\x18\x04 \x01(\x04\x12\x1c\n\x14total_quote_quantums\x18\x05 \x01(\x04\x12\x0e\n\x06is_buy\x18\x06 \x01(\x08\x12\x1b\n\x13is_final_settlement\x18\x07 \x01(\x08\"\xc7\x01\n\x12LiquidationOrderV1\x12O\n\nliquidated\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountIdB\x04\xc8\xde\x1f\x00\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x14\n\x0cperpetual_id\x18\x03 \x01(\r\x12\x12\n\ntotal_size\x18\x04 \x01(\x04\x12\x0e\n\x06is_buy\x18\x05 \x01(\x08\x12\x10\n\x08subticks\x18\x06 \x01(\x04\"\xa7\x02\n\x17SubaccountUpdateEventV1\x12L\n\rsubaccount_id\x18\x01 \x01(\x0b\x32\x35.dydxprotocol.indexer.protocol.v1.IndexerSubaccountId\x12_\n\x1bupdated_perpetual_positions\x18\x03 \x03(\x0b\x32:.dydxprotocol.indexer.protocol.v1.IndexerPerpetualPosition\x12W\n\x17updated_asset_positions\x18\x04 \x03(\x0b\x32\x36.dydxprotocol.indexer.protocol.v1.IndexerAssetPositionJ\x04\x08\x02\x10\x03\"\x8c\x0b\n\x14StatefulOrderEventV1\x12\x65\n\x0border_place\x18\x01 \x01(\x0b\x32J.dydxprotocol.indexer.events.StatefulOrderEventV1.StatefulOrderPlacementV1B\x02\x18\x01H\x00\x12\x61\n\rorder_removal\x18\x04 \x01(\x0b\x32H.dydxprotocol.indexer.events.StatefulOrderEventV1.StatefulOrderRemovalV1H\x00\x12t\n\x1b\x63onditional_order_placement\x18\x05 \x01(\x0b\x32M.dydxprotocol.indexer.events.StatefulOrderEventV1.ConditionalOrderPlacementV1H\x00\x12t\n\x1b\x63onditional_order_triggered\x18\x06 \x01(\x0b\x32M.dydxprotocol.indexer.events.StatefulOrderEventV1.ConditionalOrderTriggeredV1H\x00\x12o\n\x19long_term_order_placement\x18\x07 \x01(\x0b\x32J.dydxprotocol.indexer.events.StatefulOrderEventV1.LongTermOrderPlacementV1H\x00\x12i\n\x11order_replacement\x18\x08 \x01(\x0b\x32L.dydxprotocol.indexer.events.StatefulOrderEventV1.LongTermOrderReplacementV1H\x00\x1aY\n\x18StatefulOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1a\xa5\x01\n\x16StatefulOrderRemovalV1\x12J\n\x10removed_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12?\n\x06reason\x18\x02 \x01(\x0e\x32/.dydxprotocol.indexer.shared.OrderRemovalReason\x1a\\\n\x1b\x43onditionalOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1ak\n\x1b\x43onditionalOrderTriggeredV1\x12L\n\x12triggered_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x1aY\n\x18LongTermOrderPlacementV1\x12=\n\x05order\x18\x01 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrder\x1a\xa3\x01\n\x1aLongTermOrderReplacementV1\x12\x46\n\x0cold_order_id\x18\x01 \x01(\x0b\x32\x30.dydxprotocol.indexer.protocol.v1.IndexerOrderId\x12=\n\x05order\x18\x02 \x01(\x0b\x32..dydxprotocol.indexer.protocol.v1.IndexerOrderB\x07\n\x05\x65ventJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"r\n\x12\x41ssetCreateEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06symbol\x18\x02 \x01(\t\x12\x12\n\nhas_market\x18\x03 \x01(\x08\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x05 \x01(\x11\"\xb8\x02\n\x1cPerpetualMarketCreateEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x08 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\t \x01(\x04\x12\x16\n\x0eliquidity_tier\x18\n \x01(\r:\x02\x18\x01\"\x80\x03\n\x1cPerpetualMarketCreateEventV2\x12\n\n\x02id\x18\x01 \x01(\r\x12\x14\n\x0c\x63lob_pair_id\x18\x02 \x01(\r\x12\x0e\n\x06ticker\x18\x03 \x01(\t\x12\x11\n\tmarket_id\x18\x04 \x01(\r\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x06 \x01(\x11\x12\x19\n\x11\x61tomic_resolution\x18\x07 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x08 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\t \x01(\x04\x12\x16\n\x0eliquidity_tier\x18\n \x01(\r\x12J\n\x0bmarket_type\x18\x0b \x01(\x0e\x32\x35.dydxprotocol.indexer.protocol.v1.PerpetualMarketType\"\xd6\x01\n\x1aLiquidityTierUpsertEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08R\x17open_interest_lower_capR\x17open_interest_upper_cap\"\xcb\x01\n\x15UpdateClobPairEventV1\x12\x14\n\x0c\x63lob_pair_id\x18\x01 \x01(\r\x12@\n\x06status\x18\x02 \x01(\x0e\x32\x30.dydxprotocol.indexer.protocol.v1.ClobPairStatus\x12#\n\x1bquantum_conversion_exponent\x18\x03 \x01(\x11\x12\x19\n\x11subticks_per_tick\x18\x04 \x01(\r\x12\x1a\n\x12step_base_quantums\x18\x05 \x01(\x04\"z\n\x16UpdatePerpetualEventV1\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x11\n\tmarket_id\x18\x03 \x01(\r\x12\x19\n\x11\x61tomic_resolution\x18\x04 \x01(\x11\x12\x16\n\x0eliquidity_tier\x18\x05 \x01(\r\"c\n\x15TradingRewardsEventV1\x12J\n\x0ftrading_rewards\x18\x01 \x03(\x0b\x32\x31.dydxprotocol.indexer.events.AddressTradingReward\"\x85\x01\n\x14\x41\x64\x64ressTradingReward\x12\r\n\x05owner\x18\x01 \x01(\t\x12^\n\x0c\x64\x65nom_amount\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"k\n\x19OpenInterestUpdateEventV1\x12N\n\x15open_interest_updates\x18\x01 \x03(\x0b\x32/.dydxprotocol.indexer.events.OpenInterestUpdate\"\x8b\x01\n\x12OpenInterestUpdate\x12\x14\n\x0cperpetual_id\x18\x01 \x01(\r\x12_\n\ropen_interest\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt\"\xda\x01\n\x1aLiquidityTierUpsertEventV2\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12initial_margin_ppm\x18\x03 \x01(\r\x12 \n\x18maintenance_fraction_ppm\x18\x04 \x01(\r\x12\"\n\x16\x62\x61se_position_notional\x18\x05 \x01(\x04\x42\x02\x18\x01\x12\x1f\n\x17open_interest_lower_cap\x18\x06 \x01(\x04\x12\x1f\n\x17open_interest_upper_cap\x18\x07 \x01(\x04\x42:Z8github.com/dydxprotocol/v4-chain/protocol/indexer/eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.indexer.events.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z8github.com/dydxprotocol/v4-chain/protocol/indexer/events'
  _globals['_FUNDINGUPDATEV1'].fields_by_name['funding_index']._loaded_options = None
  _globals['_FUNDINGUPDATEV1'].fields_by_name['funding_index']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_FUNDINGEVENTV1'].fields_by_name['updates']._loaded_options = None
  _globals['_FUNDINGEVENTV1'].fields_by_name['updates']._serialized_options = b'\310\336\037\000'
  _globals['_SOURCEOFFUNDS'].fields_by_name['address']._loaded_options = None
  _globals['_SOURCEOFFUNDS'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_ORDERFILLEVENTV1'].fields_by_name['maker_order']._loaded_options = None
  _globals['_ORDERFILLEVENTV1'].fields_by_name['maker_order']._serialized_options = b'\310\336\037\000'
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['liquidated']._loaded_options = None
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['liquidated']._serialized_options = b'\310\336\037\000'
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['offsetting']._loaded_options = None
  _globals['_DELEVERAGINGEVENTV1'].fields_by_name['offsetting']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONORDERV1'].fields_by_name['liquidated']._loaded_options = None
  _globals['_LIQUIDATIONORDERV1'].fields_by_name['liquidated']._serialized_options = b'\310\336\037\000'
  _globals['_STATEFULORDEREVENTV1'].fields_by_name['order_place']._loaded_options = None
  _globals['_STATEFULORDEREVENTV1'].fields_by_name['order_place']._serialized_options = b'\030\001'
  _globals['_PERPETUALMARKETCREATEEVENTV1']._loaded_options = None
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_options = b'\030\001'
  _globals['_LIQUIDITYTIERUPSERTEVENTV1'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIERUPSERTEVENTV1'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_ADDRESSTRADINGREWARD'].fields_by_name['denom_amount']._loaded_options = None
  _globals['_ADDRESSTRADINGREWARD'].fields_by_name['denom_amount']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_OPENINTERESTUPDATE'].fields_by_name['open_interest']._loaded_options = None
  _globals['_OPENINTERESTUPDATE'].fields_by_name['open_interest']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_LIQUIDITYTIERUPSERTEVENTV2'].fields_by_name['base_position_notional']._loaded_options = None
  _globals['_LIQUIDITYTIERUPSERTEVENTV2'].fields_by_name['base_position_notional']._serialized_options = b'\030\001'
  _globals['_FUNDINGUPDATEV1']._serialized_start=319
  _globals['_FUNDINGUPDATEV1']._serialized_end=482
  _globals['_FUNDINGEVENTV1']._serialized_start=485
  _globals['_FUNDINGEVENTV1']._serialized_end=745
  _globals['_FUNDINGEVENTV1_TYPE']._serialized_start=636
  _globals['_FUNDINGEVENTV1_TYPE']._serialized_end=745
  _globals['_MARKETEVENTV1']._serialized_start=748
  _globals['_MARKETEVENTV1']._serialized_end=1020
  _globals['_MARKETPRICEUPDATEEVENTV1']._serialized_start=1022
  _globals['_MARKETPRICEUPDATEEVENTV1']._serialized_end=1077
  _globals['_MARKETBASEEVENTV1']._serialized_start=1079
  _globals['_MARKETBASEEVENTV1']._serialized_end=1142
  _globals['_MARKETCREATEEVENTV1']._serialized_start=1144
  _globals['_MARKETCREATEEVENTV1']._serialized_end=1245
  _globals['_MARKETMODIFYEVENTV1']._serialized_start=1247
  _globals['_MARKETMODIFYEVENTV1']._serialized_end=1330
  _globals['_SOURCEOFFUNDS']._serialized_start=1333
  _globals['_SOURCEOFFUNDS']._serialized_end=1483
  _globals['_TRANSFEREVENTV1']._serialized_start=1486
  _globals['_TRANSFEREVENTV1']._serialized_end=1833
  _globals['_ORDERFILLEVENTV1']._serialized_start=1836
  _globals['_ORDERFILLEVENTV1']._serialized_end=2202
  _globals['_DELEVERAGINGEVENTV1']._serialized_start=2205
  _globals['_DELEVERAGINGEVENTV1']._serialized_end=2506
  _globals['_LIQUIDATIONORDERV1']._serialized_start=2509
  _globals['_LIQUIDATIONORDERV1']._serialized_end=2708
  _globals['_SUBACCOUNTUPDATEEVENTV1']._serialized_start=2711
  _globals['_SUBACCOUNTUPDATEEVENTV1']._serialized_end=3006
  _globals['_STATEFULORDEREVENTV1']._serialized_start=3009
  _globals['_STATEFULORDEREVENTV1']._serialized_end=4429
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERPLACEMENTV1']._serialized_start=3691
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERPLACEMENTV1']._serialized_end=3780
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERREMOVALV1']._serialized_start=3783
  _globals['_STATEFULORDEREVENTV1_STATEFULORDERREMOVALV1']._serialized_end=3948
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERPLACEMENTV1']._serialized_start=3950
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERPLACEMENTV1']._serialized_end=4042
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERTRIGGEREDV1']._serialized_start=4044
  _globals['_STATEFULORDEREVENTV1_CONDITIONALORDERTRIGGEREDV1']._serialized_end=4151
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERPLACEMENTV1']._serialized_start=4153
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERPLACEMENTV1']._serialized_end=4242
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERREPLACEMENTV1']._serialized_start=4245
  _globals['_STATEFULORDEREVENTV1_LONGTERMORDERREPLACEMENTV1']._serialized_end=4408
  _globals['_ASSETCREATEEVENTV1']._serialized_start=4431
  _globals['_ASSETCREATEEVENTV1']._serialized_end=4545
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_start=4548
  _globals['_PERPETUALMARKETCREATEEVENTV1']._serialized_end=4860
  _globals['_PERPETUALMARKETCREATEEVENTV2']._serialized_start=4863
  _globals['_PERPETUALMARKETCREATEEVENTV2']._serialized_end=5247
  _globals['_LIQUIDITYTIERUPSERTEVENTV1']._serialized_start=5250
  _globals['_LIQUIDITYTIERUPSERTEVENTV1']._serialized_end=5464
  _globals['_UPDATECLOBPAIREVENTV1']._serialized_start=5467
  _globals['_UPDATECLOBPAIREVENTV1']._serialized_end=5670
  _globals['_UPDATEPERPETUALEVENTV1']._serialized_start=5672
  _globals['_UPDATEPERPETUALEVENTV1']._serialized_end=5794
  _globals['_TRADINGREWARDSEVENTV1']._serialized_start=5796
  _globals['_TRADINGREWARDSEVENTV1']._serialized_end=5895
  _globals['_ADDRESSTRADINGREWARD']._serialized_start=5898
  _globals['_ADDRESSTRADINGREWARD']._serialized_end=6031
  _globals['_OPENINTERESTUPDATEEVENTV1']._serialized_start=6033
  _globals['_OPENINTERESTUPDATEEVENTV1']._serialized_end=6140
  _globals['_OPENINTERESTUPDATE']._serialized_start=6143
  _globals['_OPENINTERESTUPDATE']._serialized_end=6282
  _globals['_LIQUIDITYTIERUPSERTEVENTV2']._serialized_start=6285
  _globals['_LIQUIDITYTIERUPSERTEVENTV2']._serialized_end=6503
# @@protoc_insertion_point(module_scope)



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class PublicKey(_message.Message):
    __slots__ = ("ed25519", "secp256k1")
    ED25519_FIELD_NUMBER: _ClassVar[int]
    SECP256K1_FIELD_NUMBER: _ClassVar[int]
    ed25519: bytes
    secp256k1: bytes
    def __init__(self, ed25519: _Optional[bytes] = ..., secp256k1: _Optional[bytes] = ...) -> None: ...
